dnl -*- coding:utf-8; mode:m4; -*-

dnl SYNOPSYS
dnl
dnl   AX_PROG_BASENAME([GNU])
dnl
dnl DESCRIPTION
dnl
dnl   Check for the `basename' program and set BASENAME to it if found.
dnl   Otherwise, define BASENAME to be the replacement script
dnl   `$ac_aux_dir/basename.sh.  If the optional parameter is given and equals
dnl   `GNU', require the `basename' program to support the additional options
dnl   accepted by GNU basename.  (The supplied replacement script supports
dnl   these so it doesn't make your package less portable if you require this
dnl   convenience.  On the other hand, if you don't need it, using a natively
dnl   compiled program will certainly be faster.)
dnl
dnl LICENSE
dnl
dnl   Copyright (c) 2013 Moritz Klammler <moritz@klammler.eu>
dnl
dnl   Copying and distribution of this file, with or without modification, are
dnl   permitted in any medium without royalty provided the copyright notice and
dnl   this notice are preserved.  This file is offered as-is, without any
dnl   warranty.
dnl
AC_DEFUN([AX_PROG_BASENAME], [
  AC_REQUIRE([AC_PROG_SED])
  AC_CHECK_PROGS([BASENAME], [basename])
  AS_IF([test "x$BASENAME" = x], [BASENAME=false], [m4_strip([
        _ax_prog_basename="$BASENAME"
        test "$($BASENAME /usr/bin/sort 2>/dev/null)" = sort || BASENAME=false
        test "$($BASENAME include/stdio.h .h 2>/dev/null)" = stdio || BASENAME=false
        test "$($BASENAME /usr/local/bin/ 2>/dev/null)" = bin || BASENAME=false
        test "$($BASENAME /usr/local/bin/. 2>/dev/null)" = . || BASENAME=false
        test "x$($BASENAME -- --help 2>/dev/null)" = x--help || BASENAME=false
      ])
      m4_if([$1], [GNU], [m4_strip([
        # Test for GNU basename features.
        test "$($BASENAME -a /bin/bar /bin/baz 2>/dev/null)" dnl
          = "$(echo bar; echo baz;)" || BASENAME=false
        test "$($BASENAME --multiple /bin/bar /bin/baz 2>/dev/null)" dnl
          = "$(echo bar; echo baz;)" || BASENAME=false
        test "$($BASENAME -s .a /usr/lib/foo.a /usr/local/lib/foo.a 2>/dev/null)" dnl
          = "$(echo foo; echo foo)" || BASENAME=false
        test "$($BASENAME --suffix=.a /usr/lib/foo.a /usr/local/lib/foo.a 2>/dev/null)" dnl
          = "$(echo foo; echo foo)" || BASENAME=false
        test "$($BASENAME -az "./white space" ./next 2>/dev/null)" dnl
          = "$(printf "white space\0next\0")" || BASENAME=false
        test "$($BASENAME -a --zero "./white space" ./next 2>/dev/null)" dnl
          = "$(printf "white space\0next\0")" || BASENAME=false
      ])], [m4_ifnblank([$1], [
        m4_fatal([AX_PROG_BASENAME: if present, the optional argument must be `GNU', not `$1'])
      ])])
      AS_IF([test "$BASENAME" = false], [
        AC_MSG_WARN([$_ax_prog_basename: does not work as expected])
        unset _ax_prog_basename
      ])
    ])
  AS_IF([test "$BASENAME" = false], [
dnl TODO: Is is correct that we use $ac_aux_dir like this?
    BASENAME="$SHELL $srcdir/$ac_aux_dir/basename.sh"
    AC_REQUIRE_AUX_FILE([basename.sh.in])
    AC_CONFIG_FILES([$srcdir/$ac_aux_dir/basename.sh])
  ])
])
